Semver |version| -- Semantic Versioning
=======================================

.. include:: readme.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents
   :hidden:
   :numbered:

   build-semver
   install
   usage/index
   migration/index
   advanced/index
   contribute/index
   api

.. toctree::
   :maxdepth: 2
   :caption: CLI
   :hidden:

   pysemver


.. toctree::
   :maxdepth: 1
   :caption: Development
   :hidden:

   changelog
   changelog-semver2


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
